
.. _`Exceptions`:

Exceptions
----------

.. automodule:: pywbem.exceptions

.. autoclass:: pywbem.Error
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.Error
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.Error
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.ConnectionError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.ConnectionError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.ConnectionError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.AuthError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.AuthError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.AuthError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.HTTPError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.HTTPError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.HTTPError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.TimeoutError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.TimeoutError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.TimeoutError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.ParseError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.ParseError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.ParseError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.CIMXMLParseError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMXMLParseError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMXMLParseError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.XMLParseError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.XMLParseError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.XMLParseError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.CIMError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.CIMError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.CIMError
      :attributes:

   .. rubric:: Details

.. autoclass:: pywbem.ModelError
   :members:

   .. rubric:: Methods

   .. autoautosummary:: pywbem.ModelError
      :methods:
      :nosignatures:

   .. rubric:: Attributes

   .. autoautosummary:: pywbem.ModelError
      :attributes:

   .. rubric:: Details
